# vrt_lss_stock
Veeroute.LSS Stock API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.8.168672
- Package version: 3.8.168672
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import vrt_lss_stock
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import vrt_lss_stock
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import vrt_lss_stock
from pprint import pprint
from vrt_lss_stock.api import plan_api
from vrt_lss_stock.model.inline_response400 import InlineResponse400
from vrt_lss_stock.model.inline_response401 import InlineResponse401
from vrt_lss_stock.model.inline_response415 import InlineResponse415
from vrt_lss_stock.model.inline_response429 import InlineResponse429
from vrt_lss_stock.model.inline_response500 import InlineResponse500
from vrt_lss_stock.model.inline_response501 import InlineResponse501
from vrt_lss_stock.model.inline_response502 import InlineResponse502
from vrt_lss_stock.model.inline_response503 import InlineResponse503
from vrt_lss_stock.model.inline_response504 import InlineResponse504
from vrt_lss_stock.model.inline_response_default import InlineResponseDefault
from vrt_lss_stock.model.plan_result import PlanResult
from vrt_lss_stock.model.plan_task import PlanTask
# Defining the host is optional and defaults to https://api.veeroute.tech/v3
# See configuration.py for a list of all supported configuration parameters.
configuration = vrt_lss_stock.Configuration(
    host = "https://api.veeroute.tech/v3"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): ApiKeyAuth
configuration = vrt_lss_stock.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)


# Enter a context with an instance of the API client
with vrt_lss_stock.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = plan_api.PlanApi(api_client)
    plan_task = PlanTask(
        storages=[
            Storage(
                key="storage_01",
                balance=Balance(
                    start_amount=2000,
                    min_limit=2000,
                    max_limit=2000,
                ),
                forecast=BalanceForecast([
                    BalanceDelta(
                        time_index=10,
                        delta=2000,
                    ),
                ]),
                tariff=StorageTariff(
                    transfer_cost=1000,
                    storage_cost=0.1,
                ),
                restricted_time_indexes=[
                    10,
                ],
            ),
        ],
    ) # PlanTask | New planning request.

    try:
        # Planning.
        api_response = api_instance.plan(plan_task)
        pprint(api_response)
    except vrt_lss_stock.ApiException as e:
        print("Exception when calling PlanApi->plan: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.veeroute.tech/v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PlanApi* | [**plan**](docs/PlanApi.md#plan) | **POST** /stock/plan | Planning.
*SystemApi* | [**check**](docs/SystemApi.md#check) | **GET** /stock/check | Checking the service availability.
*SystemApi* | [**version**](docs/SystemApi.md#version) | **GET** /stock/version | Getting the service version.
*ValidateApi* | [**validate**](docs/ValidateApi.md#validate) | **POST** /stock/validate | Data validation for planning.


## Documentation For Models

 - [Balance](docs/Balance.md)
 - [BalanceDelta](docs/BalanceDelta.md)
 - [BalanceForecast](docs/BalanceForecast.md)
 - [CheckResult](docs/CheckResult.md)
 - [InlineResponse400](docs/InlineResponse400.md)
 - [InlineResponse401](docs/InlineResponse401.md)
 - [InlineResponse415](docs/InlineResponse415.md)
 - [InlineResponse429](docs/InlineResponse429.md)
 - [InlineResponse500](docs/InlineResponse500.md)
 - [InlineResponse501](docs/InlineResponse501.md)
 - [InlineResponse502](docs/InlineResponse502.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [InlineResponse504](docs/InlineResponse504.md)
 - [InlineResponseDefault](docs/InlineResponseDefault.md)
 - [PlanResult](docs/PlanResult.md)
 - [PlanTask](docs/PlanTask.md)
 - [Storage](docs/Storage.md)
 - [StorageTariff](docs/StorageTariff.md)
 - [TraceData](docs/TraceData.md)
 - [Transfer](docs/Transfer.md)
 - [ValidateResult](docs/ValidateResult.md)
 - [Validation](docs/Validation.md)
 - [VersionResult](docs/VersionResult.md)


## Documentation For Authorization


## ApiKeyAuth

- **Type**: Bearer authentication (JWT)


## Author

support@veeroute.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in vrt_lss_stock.apis and vrt_lss_stock.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from vrt_lss_stock.api.default_api import DefaultApi`
- `from vrt_lss_stock.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import vrt_lss_stock
from vrt_lss_stock.apis import *
from vrt_lss_stock.models import *
```

